const express = require("express");
const router = express.Router();
const Transaction = require("../models/transaction");
const User = require("../models/user");
const Book = require("../models/Book");

router.get("/", function(req, res) {
  console.log("Get transaction start");
  Transaction.find({}, function(err, transactions) {
    if (err) {
      res.json({ result: false, message: "Not found transactions" });
      return;
    }
    res.json(transactions);
  });
});

router.post("/cancel", async (req, res) => {
  console.log("POST - cancel start");
  var sess = req.session;
  var req_bookTitle = req.body.bookTitle;
  var userId = sess.userid;

  try {
    await Transaction.findOne(
      {
        bookTitle: req_bookTitle,
        $or: [{ buyerId: userId }, { sellerId: userId }]
      },
      function(err, transaction) {
        if (err) {
          console.error(err);
          return;
        }
        transaction.buyerId = "";
        transaction.on_transaction = false;
        transaction.save();
        res.json({ result: true });
      }
    );
  } catch (err) {
    res.json({ error: err.message });
  }
});

router.post("/success", async (req, res) => {
  console.log("POST - success start");
  var sess = req.session;
  var req_bookTitle = req.body.bookTitle;
  var userId = sess.userid;

  try {
    await Transaction.remove(
      {
        bookTitle: req_bookTitle,
        $or: [{ buyerId: userId }, { sellerId: userId }]
      },
      function(err, transaction) {
        if (err) {
          console.error(err);
          return;
        }
        Book.findOne({ title: req_bookTitle }, function(err, book) {
          if (err) {
            console.error(err);
            return;
          }
          book.stock--;
          book.save();
        });
        // transaction.on_transaction = "";
        // transaction.save();
        res.json({ result: true });
      }
    );
  } catch (err) {
    res.json({ error: err.message });
  }
});

router.post("/buy", async (req, res) => {
  console.log("POST - buy start");
  var sess = req.session;
  var req_bookTitle = req.body.bookTitle;
  buyerId = sess.userid;

  try {
    await Transaction.findOne({ bookTitle: req_bookTitle }, function(
      err,
      transaction
    ) {
      if (err) {
        console.error(err);
        return;
      }
      transaction.buyerId = buyerId;
      transaction.on_transaction = true;
      transaction.save();
      res.json({ buyerId: buyerId, sellerId: transaction.sellerId });
    });
  } catch (err) {
    res.json({ error: err.message });
  }
});

router.post("/sell", async (req, res) => {
  console.log("POST - sell start");
  var sess = req.session;
  var bookTitle = req.body.bookTitle;
  sellerId = sess.userid;
  console.log(sellerId);

  try {
    await Book.findOne({ title: bookTitle }, function(err, book) {
      if (err) {
        console.error(err);
        return;
      }

      var transaction = new Transaction();
      transaction.sellerId = sellerId;
      transaction.buyerId = "";
      transaction.bookTitle = book.title;
      transaction.on_transaction = false;
      book.stock++;
      transaction.save();
      book.save();
      res.json({ result: true });
    });
  } catch (err) {
    res.json({ error: err.message });
  }
});

module.exports = router;
